@@ -14,6 +14,8 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <https://www.gnu.org/licenses/>.
 import base64
+from PIL import Image
+from io import BytesIO
 import time
 from ctypes import *
 import threading
@@ -27,6 +29,8 @@ import random
 from time import sleep
 import io
 from .DataStruct import *
+import operator
+from functools import reduce
 
 
 html_string_1 = "<!DOCTYPE html><html lang=\"en\"><head><meta charset=\"UTF-8\"><title>render</title></head><body style=\"background:#000;clip:rect(auto,auto,auto,auto);\"><div id=\"content\" style=\"width:"
@@ -782,3 +786,31 @@ class Item:
         :return: 截图的base64形态
         """
         return self.device.grab_image_to_base64(self.__center_x_to_global, self.__center_y_to_global, self.__width, self.__height, self.__rotation, self.__scale)
+
+    def contrast_picture(self, path: str) -> float:
+        """
+        使用本地的图片文件与当前元素控件截图进行图片比对。\n
+        :param path: 本地的图片路径
+        :return: 对比值，值越小越相似
+        """
+        self.__refresh_node()
+        current_pic = Image.open(BytesIO(base64.b64decode(self.grab_image_to_base64())))
+        target_pic = Image.open(path)
+        h1 = current_pic.histogram()
+        h2 = target_pic.histogram()
+        result = math.sqrt(reduce(operator.add, list(map(lambda a, b: (a - b) ** 2, h1, h2))) / len(h1))
+        return result
+
+    def contrast_picture_from_base64(self, pic: str) -> float:
+        """
+        使用图片的base64字符串与当前元素控件截图进行图片比对。\n
+        :param pic: 图片的base64字符串
+        :return: 对比值，值越小越相似
+        """
+        self.__refresh_node()
+        current_pic = Image.open(BytesIO(base64.b64decode(self.grab_image_to_base64())))
+        target_pic = Image.open(BytesIO(base64.b64decode(pic)))
+        h1 = current_pic.histogram()
+        h2 = target_pic.histogram()
+        result = math.sqrt(reduce(operator.add, list(map(lambda a, b: (a - b) ** 2, h1, h2))) / len(h1))
+        return result
